// Cure model using constraints

clear all
set scheme fpsaus_c
global dofile constraints_cure_model.do

use breast_nw if agegrp==5
stset survtime, f(dead=1) id(ident)

stpp R_pp using "https://pclambert.net/data/popmort_NW.dta", ///
                agediag(agediag) datediag(datediag)                            ///
                pmage(age) pmyear(year) ///
                pmother(sex dep)  graphname(R_pp2, replace) 


// Attained age
gen age = min(floor(agediag + _t),99)
// Attained calendar year
gen year = year(floor(datediag + _t*365.24))
// Merge in life tables
merge m:1 age year dep sex using popmort_NW, ///
          keep(match master) keepusing(rate)

stpm3 @ns(agediag, df(3)), scale(lncumhazard) df(5) ///
                           bhazard(rate) nolog 
            text("bhazard(rate)") 


range tt 0 10 101          
standsurv S1, surv at1(.) timevar(tt) ci frame(surv, replace)          

twoway (line R_pp _t, sort connect(stairstep)) ///
       , ytitle(Marginal relative survival)    ///
         xtitle(Years from diagnosis)          ///
         ylabel(0(0.2)1, format(%3.1f))        ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
frame surv: addplot: line S1 tt, sort          ///
            legend(order(1 "Pohar Perme" 2 "Model (no cure)"))  norescaling


stpm3 @ns(agediag, df(3)), scale(lncumhazard)               ///
      knots(20 40 60 80 95, percentile) bhazard(rate) nolog
            text("knots(20 40 60 80 95, percentile)") 
            
            
standsurv S2, surv at1(.) ci frame(surv, merge)          

twoway (line R_pp _t, sort connect(stairstep))                  ///
       , ytitle(Marginal relative survival)                     ///
         xtitle(Years from diagnosis)                           ///
         ylabel(0(0.2)1, format(%3.1f))                         ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
         
frame surv: addplot: line S1 S2 tt, sort                        ///
            legend(order(1 "Pohar Perme" 2 "Model (no cure)"    ///
                         3 "Model with extra knot (no cure)"))  ///
            norescaling

constraint 1 _ns6==0
stpm3 @ns(agediag, df(3)), scale(lncumhazard) knots(20 40 60 80 95, percentile) ///
                           bhazard(rate) constraints(1) nolog
            text("constraint 1 _ns6==0") 
            text("constraints(1)")  
            text("_ns6 {\VBAR}          0  (omitted)")              
            
            
            
standsurv S3, surv at1(.) ci frame(surv, merge)        
  
twoway (line R_pp _t, sort connect(stairstep))                  ///
       , ytitle(Marginal relative survival)                     ///
         xtitle(Years from diagnosis)                           ///
         ylabel(0(0.2)1, format(%3.1f))                         ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))

frame surv: addplot: line S1 S2 S3 tt, sort                        ///
            legend(order(1 "Pohar Perme" 2 "Model (no cure)"    ///
                         3 "Model with extra knot (no cure)"    ///
                         4 "Cure model (with constraint)"))     ///
            norescaling

gen t10 = 10 in 1
standsurv cure, surv timevar(t10) frame(cure, replace) ci at1(.)
frame cure: list cure*, noobs               


predict cure75 cure85, surv timevar(t10) ci frame(cure2, replace)   ///
                       at1(agediag 75) at2(agediag 85)              ///
                       contrast(difference) contrastvar(curediff)
frame cure2: list cure75* cure85*, noobs
frame cure2: list curediff*, noobs abbrev(12)

