// constraining hazard ratios

clear all
set scheme fpsaus_c
global dofile constraints_hazard_ratio.do

use breast_EW50 if inlist(dep,1,5)
stset survtime, f(dead=1) id(ident)

// fit model with time-dependent hazard ratio
stpm3 i.dep, scale(lnhazard) df(5) tvc(i.dep) dftvc(3) nolog vsquish

predict , hazard timevar(0 10,n(101)) ci frame(f1, replace) nogen ///
          at1(dep 1) at2(dep 5)                                   ///
          contrast(ratio) contrastvar(hr1)
          
frame f1 {
  twoway (rarea hr1_lci hr1_uci tt, color(%30))   ///
         (line hr1 tt, pstyle(p1line))            ///
         ,xtitle("Years from surgery")            ///
         ytitle("Hazard ratio")                   ///
         ylabel(,format(%3.1f))                   ///
         yline(1,lpattern(shortdash) lcolor(gs8)) ///
         legend(off)                              ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}


// obtain percentiles before 5 years
summ _t, meanonly
global mintime `r(min)'
_pctile _t if _d & _t<=5, p(33.33 66.67 95 )
global allknots  ${mintime} `r(r1)' `r(r2)' `r(r3)' `r(r4)' 5
di "${allknots}"
            text(".003000000026077 1.560999989509583 2.913000106811523 4.651999950408936  5") 


constraint 1 5.dep#c._ns_tvc4 = 0
stpm3 i.dep, scale(lnhazard) df(5) tvc(i.dep) allknotstvc(${allknots}) ///
             constraints(1) nolog vsquish
            text("constraint 1 5.dep\#c._ns_tvc4 = 0")  
            text("constraints(1)")  
            text("dep\#c._ns_tvc4 {\VBAR}") 
            text("mostdep  {\VBAR}          0  (omitted)") 
            
            
            
            
            
           

predict , hazard at1(dep 1) at2(dep 5) ci frame(f1, merge) nogen ///
          contrast(ratio) contrastvar(hr2)

frame f1 {
  twoway (rarea hr1_lci hr1_uci tt, color(%30))                  ///
         (line hr1 tt, pstyle(p1line))                           ///
         (line hr2* tt, pstyle(p2line..) lpattern(solid dash..)) ///
         ,xtitle("Years from surgery")                           ///
         ytitle("Hazard ratio")                                  ///
         ylabel(,format(%3.1f))                                  ///
         yline(1,lpattern(shortdash) lcolor(gs8))                ///
         legend(order(2 "Unconstrained HR" 3 "Constrained HR"))  ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}


          
