// log hazard models

clear all
set scheme fpsaus_c
global dofile log_hazard_models



use breast_EW50 

stset survtime, failure(dead==1) exit(time 5)

stpm3 i.dep, scale(lnhazard) df(5) eform nolog


predict Slnh*, surv ci frame(surv, replace)     ///
               timevar(0 5, step(0.1))          ///
               at1(dep 1) at2(dep 2) at3(dep 3) ///
               at4(dep 4) at5(dep 5)
            
predict hlnh*,  hazard ci frame(hazard, replace) per(1000) ///
                timevar(0 5, step(0.025))                  ///
                at1(dep 1) at2(dep 2) at3(dep 3)           ///
                at4(dep 4) at5(dep 5) 
                
stpm3 i.dep, scale(lncumhazard) df(5) eform nolog
predict SlnH*, surv ci frame(surv, merge)        ///
               at1(dep 1) at2(dep 2) at3(dep 3)  ///
               at4(dep 4) at5(dep 5)
predict hlnH*, hazard ci frame(hazard, merge) per(1000) ///
               at1(dep 1) at2(dep 2) at3(dep 3)         ///
               at4(dep 4) at5(dep 5)                

frame surv {
  twoway (line Slnh1 SlnH1 tt, pstyle(p1line..) lpattern(solid dash)) ///
         (line Slnh2 SlnH2 tt, pstyle(p2line..) lpattern(solid dash)) ///
         (line Slnh3 SlnH3 tt, pstyle(p3line..) lpattern(solid dash)) ///
         (line Slnh4 SlnH4 tt, pstyle(p4line..) lpattern(solid dash)) ///
         (line Slnh5 SlnH5 tt, pstyle(p5line..) lpattern(solid dash)) ///
         ,  xtitle("Years from diagnosis")                            ///
         ytitle("S(t)")                                               ///
         ylabel(,format(%3.1f))                                       /// 
         legend(order(1 "Least deprived" 3 "2" 5 "3" 7 "4" 9 "Most Deprived")) ///
         note("Solid lines are from log hazard model, dashed lines are from log cumulative hazard model" ///
              "Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}           

frame hazard {
  twoway (line hlnh1 hlnH1 tt, pstyle(p1line..) lpattern(solid dash)) ///
         (line hlnh2 hlnH2 tt, pstyle(p2line..) lpattern(solid dash)) ///
         (line hlnh3 hlnH3 tt, pstyle(p3line..) lpattern(solid dash)) ///
         (line hlnh4 hlnH4 tt, pstyle(p4line..) lpattern(solid dash)) ///
         (line hlnh5 hlnH5 tt, pstyle(p5line..) lpattern(solid dash)) ///
         ,  xtitle("Years from diagnosis")                            ///
         ytitle("h(t) per 1000 person years")                         ///
         ylabel(0 (20) 120 ,format(%3.1f))                                       /// 
         legend(order(1 "Least deprived" 3 "2" 5 "3" 7 "4" 9 "Most Deprived")) ///
         note("Solid lines are from log hazard model, dashed lines are from log cumulative hazard model" ///
              "Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}           
