// Marginal contrasts warning
// think about what population you are standardizing too.

clear all
set scheme fpsaus_c
global dofile standsurv_rott3_warnings


use rott3

// fit model
stpm3 i.hormon @ns(age,df(3)) @fn(exp(-0.12 * nodes),stub(enodes)), ///
      scale(lncumhazard) df(4) nolog neq(1)


// times to predict at
range tt 0 10 101

// contrast hormon=0 and hormon=1
// standardized using distribution of age & nodes for whole study population
standsurv, surv ci timevar(tt) frame(f1, replace)   ///
           at1(hormon 0) at2(hormon 1) atvar(S0 S1) ///
           contrast(difference) contrastvar(Sdiff)
frame f1: list tt S0 S1 Sdiff if tt == 10, noobs           

sts graph, by(hormon) title("") 
frame f1: addplot: (line S0 S1 tt, sort pstyle(p1line p2line)                           /// 
                        lpattern(shortdash..)),                                         ///
                        legend(order(1 "No hormonal treatment"                          ///
                                     2 "Hormonal treatment"))                           ///
                        xtitle("Years since surgery")                                   ///
                        ytitle("Proportion alive")                                      ///
                        ylabel(0.2(0.2)1)                                               ///
                        caption("Dashed lines are standardized model based estimates",  ///
                                 size(small) color(gs7))                                ///
                        note("Graph code in ${dofile}", size(vsmall)  color(gs3%50))


// table of summary statistics  
dtable  age nodes, by(hormon, nototal) cont(, stat(mean)) sample(,stat(freq))

// contrast hormon=0 and hormon=1
// standardized using distribution of age & nodes for untreated (hormon=0)
standsurv if hormon==0, surv ci timevar(tt) frame(f2, replace)   ///
                        at1(hormon 0) at2(hormon 1) atvar(S0 S1) ///
                        contrast(difference) contrastvar(Sdiff)
frame f2: list tt S0 S1 Sdiff if tt == 10, noobs         

sts graph, by(hormon) title("") 
frame f2: addplot: (line S0 S1 tt, sort pstyle(p1line p2line)                           /// 
                        lpattern(shortdash..)),                                         ///
                        legend(order(1 "No hormonal treatment"                          ///
                                     2 "Hormonal treatment"))                           ///
                        xtitle("Years since surgery")                                   ///
                        ytitle("Proportion alive")                                      ///
                        ylabel(0.2(0.2)1)                                               ///
                        caption("Dashed lines are standardized model based estimates",  ///
                                 size(small) color(gs7))                                ///
                        note("Graph code in ${dofile}", size(vsmall)  color(gs3%50))


// contrast hormon=0 and hormon=1
// standardized using distribution of age & nodes for untreated (hormon=0)
// alternative method
standsurv, surv ci timevar(tt) frame(f3, replace)                        ///
           at1(hormon 0, atif(hormon==0)) at2(hormon 1, atif(hormon==0)) ///
           atvar(S0 S1)                                                  ///
           contrast(difference) contrastvar(Sdiff)
frame f2: list tt S0 S1 Sdiff if tt == 10, noobs      

// contrast hormon=0 and hormon=1
// standardized using distribution of age & nodes for treated (hormon=1)
standsurv if hormon==1, surv ci timevar(tt) frame(f4, replace)   ///
                        at1(hormon 0) at2(hormon 1) atvar(S0 S1) ///
                        contrast(difference) contrastvar(Sdiff)
frame f4: list tt S0 S1 Sdiff if tt == 10, noobs           

sts graph, by(hormon) title("") 
frame f4: addplot: (line S0 S1 tt, sort pstyle(p1line p2line)                           /// 
                        lpattern(shortdash..)),                                         ///
                        legend(order(1 "No hormonal treatment"                          ///
                                     2 "Hormonal treatment"))                           ///
                        xtitle("Years since surgery")                                   ///
                        ytitle("Proportion alive")                                      ///
                        ylabel(0.2(0.2)1)                                               ///
                        caption("Dashed lines are standardized model based estimates",  ///
                                 size(small) color(gs7))                                ///
                        note("Graph code in ${dofile}", size(vsmall)  color(gs3%50))


                        
// contrast hormon=0 and hormon=1
// standardized using distribution of age & nodes within each level of hormon
standsurv, surv ci timevar(tt) frame(f5, replace)  ///
           over(hormon) atvar(S0 S1)               ///
           contrast(difference) contrastvar(Sdiff)
frame f5: list tt S0 S1 Sdiff if tt == 10, noobs           

sts graph, by(hormon) title("") 
frame f5: addplot: (line S0 S1 tt, sort pstyle(p1line p2line)                           /// 
                        lpattern(shortdash..)),                                         ///
                        legend(order(1 "No hormonal treatment"                          ///
                                     2 "Hormonal treatment"))                           ///
                        xtitle("Years since surgery")                                   ///
                        ytitle("Proportion alive")                                      ///
                        ylabel(0.2(0.2)1)                                               ///
                        caption("Dashed lines are standardized model based estimates",  ///
                                 size(small) color(gs7))                                ///
                        note("Graph code in ${dofile}", size(vsmall)  color(gs3%50))

                        
// contrast hormon=0 and hormon=1
// standardized using distribution of age & nodes within each level of hormon
// alternative method
standsurv, surv ci timevar(tt) frame(f6, replace)                        ///
           at1(hormon 0, atif(hormon==0)) at2(hormon 1, atif(hormon==1)) ///
           atvar(S0 S1)                                                  ///
           contrast(difference) contrastvar(Sdiff)  
frame f6: list tt S0 S1 Sdiff if tt == 10, noobs           
           
