// Relative survival

clear all
set scheme fpsaus_c
global dofile stpm3_relative_survival.do

frames reset 

//England and Wales Breast Data NORTH-WEST REGION

//The key to excess mortality modelling is to merge
//the expected mortality rate at the event time
//We calculate the attained age and calendar year at _t

use breast_NW

stset dateexit, origin(datediag) failure(dead==1) ///
exit(time datediag+5*365.24) id(ident) scale(365.24)

gen age = int(min(agediag + _t,99))
gen year = year(datediag+ _t*365.24)

//Merge in the expected rate
merge m:1 sex dep year age using popmort_NW /// 
     , keepusing(rate) keep(match)




//Excess mortality model - Proportional excess hazards for agegroup
stpm3 @ns(agediag, df(3))##i.dep, scale(lncumhazard) df(7) bhazard(rate) neq(0) ///
                               tvc(@ns(agediag,df(3)) i.dep) dftvc(3) nolog vsquish


// Covariate specific relative survival 
predict RS_a75_d1, survival at1(agediag 75 dep 1) ci    ///
           timevar(0 10, step(0.1))                      ///
           frame(rs_pred,replace)                          

// Covariate specific all-cause survival 
predict AC_a75_d1, survival at1(agediag 75 dep 1) ci  ///
           frame(rs_pred,merge)                       ///
           expsurv(using(popmort_NW)                  ///
           agediag(75) datediag(1990-1-1)             ///
           pmage(age) pmrate(rate) pmyear(year)       ///
           pmother(sex dep) at1(sex 2 dep 1)          ///
		       pmmaxyear(1995) pmmaxage(99))


// plot graph
frame rs_pred {
   twoway (line RS_a75_d1 AC_a75_d1 tt, sort)                                ///
          (rarea RS_a75_d1_lci RS_a75_d1_uci tt, pstyle(p1line) color(%30))  ///
          (rarea AC_a75_d1_lci AC_a75_d1_uci tt, pstyle(p2line) color(%30))  ///
	    , ylabel(0(0.1)1, format(%2.1f))                                       ///
	      ytitle("Survival")                                                   ///
	      xtitle("Time since diagnosis (years)")                               ///
        legend(order(1 "relative survival" 2 "All cause survival"))          ///
	      note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
} 	

